@@ -1,7 +1,7 @@
 package Dist::Inkt::Role::WriteMakefilePL;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.020';
+our $VERSION   = '0.021';
 
 use Moose::Role;
 use Types::Standard -types;
@@ -140,7 +140,7 @@ sub conflict_check_code
 for my $stage (keys %{$meta->{prereqs}})
 {
 	my $conflicts = $meta->{prereqs}{$stage}{conflicts} or next;
-	require CPAN::Meta::Requirements;
+	eval { require CPAN::Meta::Requirements } or last;
 	$conflicts = 'CPAN::Meta::Requirements'->from_string_hash($conflicts);
 	
 	for my $module ($conflicts->required_modules)
